@@ -110,7 +110,7 @@ def fis_preprocessing_ranking_mi(mutual_selector, predictors_df, modo = 'tabla')
         g.set_yticklabels(ranking_mi.sort_values(by = 'importancia_mi').variable)
         return(g)
 
-def fis_preprocessing_ranking_per(predictoras,rfe_ranking):
+def fis_preprocessing_ranking_rfe(predictoras,rfe_ranking):
     """
     Salida Mejorada de la salida from sklearn.feature_selection import RFECV
     """
